==> haskell-http-conduit-2.3.8-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-conduit
version:              2.3.8
visibility:           public
id:                   http-conduit-2.3.8-JW5fv7Sv3zWKCHnRiR4n8Y
key:                  http-conduit-2.3.8-JW5fv7Sv3zWKCHnRiR4n8Y
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/http-conduit
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  1ad8e75b607dd161ebef35074d42aada
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.0.1/site-local/http-conduit-2.3.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/http-conduit-2.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/http-conduit-2.3.8
hs-libraries:         HShttp-conduit-2.3.8-JW5fv7Sv3zWKCHnRiR4n8Y
depends:
    aeson-1.5.6.0-BNspgXAzKp6CkIs2quQxij
    attoparsec-0.14.1-K3GEu9KsQZ4BOtaACmx2c3 base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.1-BLONhohY05o3DaB794imz5
    conduit-extra-1.3.5-IrEqOTG0YtZ998gc47gxHl
    http-client-0.7.8-JF57Uz6k97nLmqDGQ4NJhe
    http-client-tls-0.3.5.3-2zqI9T5QGaV9kWZPqqXga9
    http-types-0.12.3-5OQIfWo1epLjmhOdBpvcY mtl-2.2.2
    resourcet-1.2.4.2-C19MLccVwM3ICk9gxUD8Z6 transformers-0.5.6.2
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.8-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-conduit
version:              2.3.8
visibility:           public
id:                   http-conduit-2.3.8-KMGSnoc3nD5J647xCTdRfs
key:                  http-conduit-2.3.8-KMGSnoc3nD5J647xCTdRfs
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/http-conduit
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  5773fccab038c2ff7d2e3b82c78c6d13
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.0.1/site-local/http-conduit-2.3.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/http-conduit-2.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/http-conduit-2.3.8
hs-libraries:         HShttp-conduit-2.3.8-KMGSnoc3nD5J647xCTdRfs
depends:
    aeson-1.5.6.0-9o8y4QVT0ed6zIp89KPO7i
    attoparsec-0.14.1-5l1cFZrGW545rXZu8IvVx4 base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.1-K5eDu05qjl0KVIYFvTpDgh
    conduit-extra-1.3.5-Kpf4PFF0Y5x6rqbvxv9I3r
    http-client-0.7.8-25QqChzgp0q9j6ealXbwz
    http-client-tls-0.3.5.3-2NopcBeZBikAvXm9rALndj
    http-types-0.12.3-EsczPCiHgMfDgCbh8KUGRq mtl-2.2.2
    resourcet-1.2.4.2-DeH26qhPbHtGqmnagpMjR9 transformers-0.5.6.2
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
